overclock::core

Struct ActorError

pub struct ActorError {
    pub source: Error,
    pub request: Option<ActorRequest>,
}
An actor’s error which contains an optional request for the supervisor

Fields

source: Error

The error source

request: Option<ActorRequest>

The actor request

Implementations

Source

impl ActorError

pub fn exit<E: Into<Error>>(error: E) -> Self

Create exit error from anyhow error

pub fn exit_msg<E>(msg: E) -> Self
where E: Display + Debug + Send + Sync + 'static,

Create exit error from message

pub fn aborted<E: Into<Error>>(error: E) -> Self

Create Aborted error from anyhow::error, note: this soft error

pub fn aborted_msg<E>(msg: E) -> Self
where E: Display + Debug + Send + Sync + 'static,

Create Aborted error from message, note: this soft error

pub fn restart<E: Into<Error>, D: Into<Option<Duration>>>( error: E, after: D, ) -> Self

Create restart error, it means the actor is asking the supervisor for restart/reschedule if possible

pub fn restart_msg<E, D: Into<Option<Duration>>>(msg: E, after: D) -> Self
where E: Display + Debug + Send + Sync + 'static,

Create restart error, it means the actor is asking the supervisor for restart/reschedule if possible